You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pdfbox.apache.org by ms...@apache.org on 2014/10/26 19:18:39 UTC

svn commit: r1634371 - in /pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight: ./ action/ annotation/ content/ exception/ font/ font/descriptor/ graphic/ metadata/ parser/ process/ process/reflect/ utils/

Author: msahyoun
Date: Sun Oct 26 18:18:37 2014
New Revision: 1634371

URL: http://svn.apache.org/r1634371
Log:
PDFBOX-2155 fix javadoc warnings in preflight

Modified:
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightContext.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightPath.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/AbstractActionManager.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ActionManagerFactory.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToAction.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToRemoteAction.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/NamedAction.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/SubmitAction.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ThreadAction.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/UriAction.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidatorFactory.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LineAnnotationValidator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LinkAnnotationValidator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/SquareCircleAnnotationValidator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/WidgetAnnotationValidator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/PreflightContentStream.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/StubOperator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/exception/PdfParseException.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/DescendantFontValidator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/Type0FontValidator.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/descriptor/FontDescriptorHelper.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelper.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelperFactory.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ICCProfileWrapper.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/StandardColorSpaceHelper.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/PDFAIdentificationValidation.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/RDFAboutAttributeConcordanceValidation.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/SynchronizedMetaDataValidation.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/parser/PreflightParser.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/AcroFormValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/BookmarkValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/CatalogValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/FileSpecificationValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/MetadataValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/StreamValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/TrailerValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ExtGStateValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/FontValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ShaddingPatternValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/SinglePageValidationProcess.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/COSUtils.java
    pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/PdfElementParser.java

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightContext.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightContext.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightContext.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightContext.java Sun Oct 26 18:18:37 2014
@@ -176,8 +176,8 @@ public class PreflightContext implements
     /**
      * Add a FontContainer to allow TextObject validation.
      * 
-     * @param fKey
-     * @param fc
+     * @param cBase the COSBase for the font container.
+     * @param fc the font container.
      */
     public void addFontContainer(COSBase cBase, FontContainer fc)
     {
@@ -188,8 +188,8 @@ public class PreflightContext implements
      * Return the FontContainer identified by the COSBase. If the given object is missing from the
      * {@link #fontContainers} map, the null value is returned.
      * 
-     * @param fKey
-     * @return
+     * @param cBase the COSBase for the font container
+     * @return the font container.
      */
     public FontContainer getFontContainer(COSBase cBase)
     {
@@ -245,7 +245,7 @@ public class PreflightContext implements
     /**
      * Add the given errors the PreflightDocument
      * 
-     * @param error
+     * @param errors the list of validation errors.
      */
     public void addValidationErrors(List<ValidationError> errors)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightPath.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightPath.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightPath.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightPath.java Sun Oct 26 18:18:37 2014
@@ -55,7 +55,7 @@ public class PreflightPath
      * 
      * @param position
      * @param expectedType
-     * @return
+     * @return the object at the given position.
      */
     @SuppressWarnings("unchecked")
     public <T> T getPathElement(int position, Class<T> expectedType)
@@ -93,7 +93,7 @@ public class PreflightPath
     /**
      * Looks at the object at the top of this stack without removing it from the stack.
      * 
-     * @return
+     * @return the object at the top of the stack.
      */
     public Object peek()
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/AbstractActionManager.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/AbstractActionManager.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/AbstractActionManager.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/AbstractActionManager.java Sun Oct 26 18:18:37 2014
@@ -113,11 +113,9 @@ public abstract class AbstractActionMana
     }
 
     /**
-     * Call the valid(boolean, List) method with the additonalActionAuth set to false.
+     * Call the {@link AbstractActionManager#valid(boolean)} method with the additonalActionAuth set to false.
      * 
-     * @param error
-     *            the validation error list to updated if the validation fails.
-     * @return
+     * @return the validation state.
      * @throws ValidationException
      */
     public boolean valid() throws ValidationException
@@ -138,7 +136,7 @@ public abstract class AbstractActionMana
      * 
      * @param additonalActionAuth
      *            boolean to know if an additional action is authorized.
-     * @return
+     * @return the validation state of the Action dictionary.
      * @throws ValidationException
      */
     public boolean valid(boolean additonalActionAuth) throws ValidationException

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ActionManagerFactory.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ActionManagerFactory.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ActionManagerFactory.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ActionManagerFactory.java Sun Oct 26 18:18:37 2014
@@ -70,9 +70,9 @@ public class ActionManagerFactory
      * 
      * If there are no action, an empty list is returned.
      * 
-     * @param dictionary
-     * @param cDoc
-     * @return
+     * @param ctx the preflight context.
+     * @param dictionary the dictionary to retrieve the actions from.
+     * @return the list of actions from the given dictionary.
      * @throws ValidationException
      */
     public final List<AbstractActionManager> getActionManagers(PreflightContext ctx, COSDictionary dictionary)
@@ -185,11 +185,9 @@ public class ActionManagerFactory
      * Returns all actions contained by the Next entry. If the action dictionary doesn't have Next action, the result is
      * an empty list.
      * 
-     * @param actionDictionary
-     *            the action dictionary which contains Next entry
-     * @param cDoc
-     *            the COSDocument which contains actions.
-     * @return
+     * @param ctx the preflight context.
+     * @param actionDictionary the dictionary to retrieve the actions from.
+     * @return the list of actions from the given dictionary.
      * @throws ValidationException
      */
     public final List<AbstractActionManager> getNextActions(PreflightContext ctx, COSDictionary actionDictionary)
@@ -226,12 +224,12 @@ public class ActionManagerFactory
      * 
      * If the action type isn't authorized in a PDF/A file, an instance of InvalidAction is returned.
      * 
-     * @param ctx
+     * @param ctx the preflight context.
      * @param action
      *            the action dictionary used to instantiate the ActionManager
-     * @param isAA
+     * @param aaKey
      *            the Action identifier if it is an additional action
-     * @return
+     * @return the ActionManager instance.
      * @throws ValidationException
      */
     protected AbstractActionManager createActionManager(PreflightContext ctx, COSDictionary action, String aaKey)

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToAction.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToAction.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToRemoteAction.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToRemoteAction.java Sun Oct 26 18:18:37 2014
@@ -37,14 +37,10 @@ public class GoToRemoteAction extends Go
 
     /**
      * 
-     * @param amFact
-     *            Instance of ActionManagerFactory used to create ActionManager to check Next actions.
-     * @param adict
-     *            the COSDictionary of the action wrapped by this class.
-     * @param cDoc
-     *            the COSDocument from which the action comes from.
-     * @param aaKey
-     *            The name of the key which identify the action in a additional action dictionary.
+     * @param amFact Instance of ActionManagerFactory used to create ActionManager to check Next actions.
+     * @param adict the COSDictionary of the action wrapped by this class.
+     * @param ctx the preflight context´.
+     * @param aaKey the name of the key which identify the action in a additional action dictionary.
      */
     public GoToRemoteAction(ActionManagerFactory amFact, COSDictionary adict, PreflightContext ctx, String aaKey)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/NamedAction.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/NamedAction.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/NamedAction.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/NamedAction.java Sun Oct 26 18:18:37 2014
@@ -46,14 +46,10 @@ public class NamedAction extends Abstrac
 {
 
     /**
-     * @param amFact
-     *            Instance of ActionManagerFactory used to create ActionManager to check Next actions.
-     * @param adict
-     *            the COSDictionary of the action wrapped by this class.
-     * @param cDoc
-     *            the COSDocument from which the action comes from.
-     * @param aaKey
-     *            The name of the key which identify the action in a additional action dictionary.
+     * @param amFact Instance of ActionManagerFactory used to create ActionManager to check Next actions.
+     * @param adict the COSDictionary of the action wrapped by this class.
+     * @param ctx the preflight context.
+     * @param aaKey the name of the key which identify the action in a additional action dictionary.
      */
     public NamedAction(ActionManagerFactory amFact, COSDictionary adict, PreflightContext ctx, String aaKey)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/SubmitAction.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/SubmitAction.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/SubmitAction.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/SubmitAction.java Sun Oct 26 18:18:37 2014
@@ -36,14 +36,10 @@ public class SubmitAction extends Abstra
 {
 
     /**
-     * @param amFact
-     *            Instance of ActionManagerFactory used to create ActionManager to check Next actions.
-     * @param adict
-     *            the COSDictionary of the action wrapped by this class.
-     * @param cDoc
-     *            the COSDocument from which the action comes from.
-     * @param aaKey
-     *            The name of the key which identify the action in a additional action dictionary.
+     * @param amFact Instance of ActionManagerFactory used to create ActionManager to check Next actions.
+     * @param adict the COSDictionary of the action wrapped by this class.
+     * @param ctx the preflight context.
+     * @param aaKey the name of the key which identify the action in a additional action dictionary.
      */
     public SubmitAction(ActionManagerFactory amFact, COSDictionary adict, PreflightContext ctx, String aaKey)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ThreadAction.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ThreadAction.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ThreadAction.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/ThreadAction.java Sun Oct 26 18:18:37 2014
@@ -39,14 +39,10 @@ public class ThreadAction extends Abstra
 {
 
     /**
-     * @param amFact
-     *            Instance of ActionManagerFactory used to create ActionManager to check Next actions.
-     * @param adict
-     *            the COSDictionary of the action wrapped by this class.
-     * @param cDoc
-     *            the COSDocument from which the action comes from.
-     * @param aaKey
-     *            The name of the key which identify the action in a additional action dictionary.
+     * @param amFact Instance of ActionManagerFactory used to create ActionManager to check Next actions.
+     * @param adict the COSDictionary of the action wrapped by this class.
+     * @param ctx the preflight context.
+     * @param aaKey the name of the key which identify the action in a additional action dictionary.
      */
     public ThreadAction(ActionManagerFactory amFact, COSDictionary adict, PreflightContext ctx, String aaKey)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/UriAction.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/UriAction.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/UriAction.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/UriAction.java Sun Oct 26 18:18:37 2014
@@ -39,14 +39,10 @@ public class UriAction extends AbstractA
 {
 
     /**
-     * @param amFact
-     *            Instance of ActionManagerFactory used to create ActionManager to check Next actions.
-     * @param adict
-     *            the COSDictionary of the action wrapped by this class.
-     * @param cDoc
-     *            the COSDocument from which the action comes from.
-     * @param aaKey
-     *            The name of the key which identify the action in a additional action dictionary.
+     * @param amFact Instance of ActionManagerFactory used to create ActionManager to check Next actions.
+     * @param adict the COSDictionary of the action wrapped by this class.
+     * @param ctx the preflight context-
+     * @param aaKey the name of the key which identify the action in a additional action dictionary.
      */
     public UriAction(ActionManagerFactory amFact, COSDictionary adict, PreflightContext ctx, String aaKey)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidator.java Sun Oct 26 18:18:37 2014
@@ -103,7 +103,7 @@ public abstract class AnnotationValidato
      * Check if the CA value is 1.0. Return true if the CA element is missing or if the value is 1.0. Return false
      * otherwise and update the list of errors present in the DocumentHandler.
      * 
-     * @return
+     * @return true if the CA element is missing or if the value is 1.0.
      */
     protected boolean checkCA()
     {
@@ -125,7 +125,7 @@ public abstract class AnnotationValidato
      * Return true if the C field is present in the Annotation dictionary and if the RGB profile is used in the
      * DestOutputProfile of the OutputIntent dictionary.
      * 
-     * @return
+     * @return true if the C field is present and the RGB profile is used.
      */
     protected boolean checkColors() throws ValidationException
     {
@@ -164,7 +164,7 @@ public abstract class AnnotationValidato
      * 
      * If the AP content isn't valid, this method return false and updates the errors list.
      * 
-     * @return
+     * @return the validation state of the AP content.
      */
     protected boolean checkAP() throws ValidationException
     {
@@ -211,7 +211,7 @@ public abstract class AnnotationValidato
      * errors list is updated and the method returns false. Otherwise, the method returns true and the errors list
      * doesn't change.
      * 
-     * @return
+     * @return the validation state of the annotations actions.
      * @throws ValidationException
      */
     protected boolean checkActions() throws ValidationException
@@ -284,7 +284,7 @@ public abstract class AnnotationValidato
 
     /**
      * Override this method to check the presence of specific fields
-     * @return
+     * @return the presence of specific fields.
      */
     protected boolean checkSpecificMandatoryFields()
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidatorFactory.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidatorFactory.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidatorFactory.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/AnnotationValidatorFactory.java Sun Oct 26 18:18:37 2014
@@ -64,9 +64,9 @@ public abstract class AnnotationValidato
     /**
      * Return an instance of AnnotationValidator.
      * 
-     * @param ctx
-     * @param annotDic
-     * @return
+     * @param ctx the preflight context.
+     * @param annotDic the annotation dictionary.
+     * @return the AnnotationValidator instance.
      */
     public final AnnotationValidator getAnnotationValidator(PreflightContext ctx, COSDictionary annotDic)
             throws ValidationException

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LineAnnotationValidator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LineAnnotationValidator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LineAnnotationValidator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LineAnnotationValidator.java Sun Oct 26 18:18:37 2014
@@ -50,7 +50,7 @@ public class LineAnnotationValidator ext
     /**
      * In addition of the AnnotationValidator.validate() method, this method executes the the checkIColors method.
      * 
-     * @see org.apache.padaf.preflight.annotation.AnnotationValidator#validate(java.util.List)
+     * @see AnnotationValidator#validate()
      */
     @Override
     public boolean validate() throws ValidationException
@@ -64,9 +64,7 @@ public class LineAnnotationValidator ext
      * Return true if the IC field is present in the Annotation dictionary and if the RGB profile is used in the
      * DestOutputProfile of the OutputIntent dictionary.
      * 
-     * @param errors
-     *            list of errors with is updated if no RGB profile is found when the IC element is present
-     * @return
+     * @return the state of the IC field validation.
      */
     protected boolean checkIColors() throws ValidationException
     {
@@ -85,7 +83,7 @@ public class LineAnnotationValidator ext
     /*
      * (non-Javadoc)
      * 
-     * @seenet.awl.edoc.pdfa.validation.annotation.AnnotationValidator# checkMandatoryFields(java.util.List)
+     * @see AnnotationValidator#checkMandatoryFields()
      */
     protected boolean checkSpecificMandatoryFields()
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LinkAnnotationValidator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LinkAnnotationValidator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LinkAnnotationValidator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/LinkAnnotationValidator.java Sun Oct 26 18:18:37 2014
@@ -53,7 +53,7 @@ public class LinkAnnotationValidator ext
     /**
      * In addition of the AnnotationValidator.validate() method, this method executes the the checkDest method.
      * 
-     * @see org.apache.padaf.preflight.annotation.AnnotationValidator#validate()
+     * @see AnnotationValidator#validate()
      */
     @Override
     public boolean validate() throws ValidationException
@@ -66,7 +66,7 @@ public class LinkAnnotationValidator ext
     /**
      * Check if the Dest element is authorized according to the A entry
      * 
-     * @return
+     * @return if the Dest element is authorized according to the A entry.
      */
     protected boolean checkDest()
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/SquareCircleAnnotationValidator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/SquareCircleAnnotationValidator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/SquareCircleAnnotationValidator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/SquareCircleAnnotationValidator.java Sun Oct 26 18:18:37 2014
@@ -49,7 +49,7 @@ public class SquareCircleAnnotationValid
     /**
      * In addition of the AnnotationValidator.validate() method, this method executes the the checkIColors method.
      * 
-     * @see org.apache.padaf.preflight.annotation.AnnotationValidator#validate(java.util.List)
+     * @see AnnotationValidator#validate()
      */
     @Override
     public boolean validate() throws ValidationException
@@ -63,9 +63,7 @@ public class SquareCircleAnnotationValid
      * Return true if the IC field is present in the Annotation dictionary and if the RGB profile is used in the
      * DestOutputProfile of the OutputIntent dictionary.
      * 
-     * @param errors
-     *            list of errors with is updated if no RGB profile is found when the IC element is present
-     * @return
+     * @return the validation state of the IC field.
      */
     protected boolean checkIColors() throws ValidationException
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/WidgetAnnotationValidator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/WidgetAnnotationValidator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/WidgetAnnotationValidator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/annotation/WidgetAnnotationValidator.java Sun Oct 26 18:18:37 2014
@@ -49,7 +49,7 @@ public class WidgetAnnotationValidator e
     /**
      * In addition of the AnnotationValidator.validate() method, this method executes the the checkAAField method.
      * 
-     * @see org.apache.padaf.preflight.annotation.AnnotationValidator#validate(java.util.List)
+     * @see AnnotationValidator#validate()
      */
     @Override
     public boolean validate() throws ValidationException
@@ -63,7 +63,7 @@ public class WidgetAnnotationValidator e
      * The AA field is forbidden for the Widget annotation when the PDF is a PDF/A. This method return false and update
      * the errors list if this key is present. returns true otherwise
      * 
-     * @return
+     * @return false if the forbidden AA field is existing.
      */
     protected boolean checkAAField()
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/PreflightContentStream.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/PreflightContentStream.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/PreflightContentStream.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/PreflightContentStream.java Sun Oct 26 18:18:37 2014
@@ -60,7 +60,6 @@ public class PreflightContentStream exte
     /**
      * Process the validation of a PageContent (The page is initialized by the constructor)
      *
-     * @return A list of validation error. This list is empty if the validation succeed.
      * @throws ValidationException
      */
     public void validPageContentStream() throws ValidationException
@@ -86,8 +85,7 @@ public class PreflightContentStream exte
     /**
      * Process the validation of a XObject Form
      * 
-     * @param form
-     * @return A list of validation error. This list is empty if the validation succeed.
+     * @param form the PDFormXObject to be validated.
      * @throws ValidationException
      */
     public void validXObjContentStream(PDFormXObject form) throws ValidationException
@@ -117,8 +115,7 @@ public class PreflightContentStream exte
     /**
      * Process the validation of a Tiling Pattern
      * 
-     * @param pattern
-     * @return A list of validation error. This list is empty if the validation succeed.
+     * @param pattern the PDTilingPattern to be validated.
      * @throws ValidationException
      */
     public void validPatternContentStream(PDTilingPattern pattern) throws ValidationException

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/StubOperator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/StubOperator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/StubOperator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/content/StubOperator.java Sun Oct 26 18:18:37 2014
@@ -406,7 +406,7 @@ public class StubOperator extends Operat
     /**
      * Create a ContentStreamException with ERROR_SYNTAX_CONTENT_STREAM_INVALID_ARGUMENT.
      * 
-     * @return
+     * @return the ContentStreamException created.
      */
     private ContentStreamException createInvalidArgumentsError()
     {
@@ -418,7 +418,7 @@ public class StubOperator extends Operat
     /**
      * Create a ContentStreamException with ERROR_SYNTAX_CONTENT_STREAM_INVALID_ARGUMENT.
      * 
-     * @return
+     * @return the ContentStreamException created.
      */
     private ContentStreamException createLimitError(String errorCode, String details)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/exception/PdfParseException.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/exception/PdfParseException.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/exception/PdfParseException.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/exception/PdfParseException.java Sun Oct 26 18:18:37 2014
@@ -91,7 +91,7 @@ public class PdfParseException extends P
     /**
      * Get the validation error code
      * 
-     * @return
+     * @return the validation error code.
      */
     public String getErrorCode()
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/DescendantFontValidator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/DescendantFontValidator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/DescendantFontValidator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/DescendantFontValidator.java Sun Oct 26 18:18:37 2014
@@ -123,7 +123,6 @@ public abstract class DescendantFontVali
      *
      * @param ctog
      * @param mandatory true for CIDType2 , false for CIDType0
-     * @return
      */
     protected void checkCIDToGIDMap(COSBase ctog, boolean mandatory)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/Type0FontValidator.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/Type0FontValidator.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/Type0FontValidator.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/Type0FontValidator.java Sun Oct 26 18:18:37 2014
@@ -238,7 +238,6 @@ public class Type0FontValidator extends 
      * using the CMapParser of the fontbox api.
      * 
      * @param aCMap
-     * @return
      */
     private void processCMapAsStream(COSStream aCMap)
     {
@@ -301,7 +300,7 @@ public class Type0FontValidator extends 
      * </UL>
      * 
      * @param sysinfo
-     * @return
+     * @return the validation result.
      */
     protected boolean checkCIDSystemInfo(COSBase sysinfo)
     {
@@ -335,7 +334,6 @@ public class Type0FontValidator extends 
      * is Identity-H or Identity-V so this method is called by the checkCMap method.
      * 
      * @param cmap
-     * @return
      */
     private void compareCIDSystemInfo(COSDictionary cmap)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/descriptor/FontDescriptorHelper.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/descriptor/FontDescriptorHelper.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/descriptor/FontDescriptorHelper.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/font/descriptor/FontDescriptorHelper.java Sun Oct 26 18:18:37 2014
@@ -196,7 +196,7 @@ public abstract class FontDescriptorHelp
      * Return true if the FontDescriptor has only one FontFile entry.
      * 
      * @param fontDescriptor
-     * @return
+     * @return true if the FontDescriptor has only one FontFile entry.
      */
     protected boolean hasOnlyOneFontFile(PDFontDescriptor fontDescriptor)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelper.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelper.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelper.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelper.java Sun Oct 26 18:18:37 2014
@@ -28,7 +28,6 @@ public interface ColorSpaceHelper
     /**
      * Process the ColorSpace validation.
      * 
-     * @param result
      */
     public void validate() throws ValidationException;
 

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelperFactory.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelperFactory.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelperFactory.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ColorSpaceHelperFactory.java Sun Oct 26 18:18:37 2014
@@ -44,7 +44,7 @@ public class ColorSpaceHelperFactory
      *            the High level PDFBox object which represents the ColorSpace
      * @param csr
      *            the color space restriction
-     * @return
+     * @return the ColorSpaceHelper instance. 
      */
     public ColorSpaceHelper getColorSpaceHelper(PreflightContext context, PDColorSpace cs, ColorSpaceRestriction csr)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ICCProfileWrapper.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ICCProfileWrapper.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ICCProfileWrapper.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/ICCProfileWrapper.java Sun Oct 26 18:18:37 2014
@@ -65,7 +65,7 @@ public class ICCProfileWrapper
     /**
      * Call the ICC_ColorSpace.getType method and return the value.
      * 
-     * @return
+     * @return the color space type.
      */
     public int getColorSpaceType()
     {
@@ -83,7 +83,7 @@ public class ICCProfileWrapper
     /**
      * Return true if the ColourSpace is RGB
      * 
-     * @return
+     * @return true if the ColourSpace is RGB. 
      */
     public boolean isRGBColorSpace()
     {
@@ -93,7 +93,7 @@ public class ICCProfileWrapper
     /**
      * Return true if the ColourSpace is CMYK
      * 
-     * @return
+     * @return true if the ColourSpace is CMYK.
      */
     public boolean isCMYKColorSpace()
     {
@@ -103,7 +103,7 @@ public class ICCProfileWrapper
     /**
      * Return true if the ColourSpace is Gray scale
      * 
-     * @return
+     * @return true if the ColourSpace is gray scale.
      */
     public boolean isGrayColorSpace()
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/StandardColorSpaceHelper.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/StandardColorSpaceHelper.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/StandardColorSpaceHelper.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/graphic/StandardColorSpaceHelper.java Sun Oct 26 18:18:37 2014
@@ -96,11 +96,7 @@ public class StandardColorSpaceHelper im
     /**
      * Method called by the validate method. According to the ColorSpace, a specific ColorSpace method is called.
      * 
-     * @param pdcs
-     *            the color space object to check.
-     * @param result
-     *            the list of error to update if the validation fails.
-     * @return true if the validation succeed, false otherwise.
+     * @param pdcs the color space object to check.
      */
     protected final void processAllColorSpace(PDColorSpace pdcs)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/PDFAIdentificationValidation.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/PDFAIdentificationValidation.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/PDFAIdentificationValidation.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/PDFAIdentificationValidation.java Sun Oct 26 18:18:37 2014
@@ -48,11 +48,8 @@ public class PDFAIdentificationValidatio
     /**
      * Check if PDFAIdentification is valid
      * 
-     * @param document
-     *            the PDF Document
-     * @param metadata
-     *            the XMP MetaData
-     * @return List of validation errors
+     * @param metadata the XMP MetaData.
+     * @return the list of validation errors.
      * @throws ValidationException
      */
     public List<ValidationError> validatePDFAIdentifer(XMPMetadata metadata) throws ValidationException
@@ -92,7 +89,7 @@ public class PDFAIdentificationValidatio
      * @param prefFound
      * @param prefExpected
      * @param schema
-     * @return
+     * @return the validation error.
      */
     protected ValidationError unexpectedPrefixFoundError(String prefFound, String prefExpected, String schema)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/RDFAboutAttributeConcordanceValidation.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/RDFAboutAttributeConcordanceValidation.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/RDFAboutAttributeConcordanceValidation.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/RDFAboutAttributeConcordanceValidation.java Sun Oct 26 18:18:37 2014
@@ -38,8 +38,7 @@ public class RDFAboutAttributeConcordanc
 
     /**
      * 
-     * @param metadata
-     * @return
+     * @param metadata the XMP metadata.
      * @throws DifferentRDFAboutException
      * @throws ValidationException
      */

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/SynchronizedMetaDataValidation.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/SynchronizedMetaDataValidation.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/SynchronizedMetaDataValidation.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/metadata/SynchronizedMetaDataValidation.java Sun Oct 26 18:18:37 2014
@@ -52,12 +52,9 @@ public class SynchronizedMetaDataValidat
     /**
      * Analyze if Title embedded in Document Information dictionary and in XMP properties are synchronized
      * 
-     * @param dico
-     *            Document Information Dictionary
-     * @param dc
-     *            Dublin Core Schema
-     * @param ve
-     *            The list of validation errors
+     * @param dico the Document Information Dictionary.
+     * @param dc the Dublin Core Schema.
+     * @param ve the list of validation errors.
      */
     protected void analyzeTitleProperty(PDDocumentInformation dico, DublinCoreSchema dc, List<ValidationError> ve)
     {
@@ -496,7 +493,7 @@ public class SynchronizedMetaDataValidat
      * @param prefFound
      * @param prefExpected
      * @param schema
-     * @return
+     * @return the generated validation error.
      */
     protected ValidationError unexpectedPrefixFoundError(String prefFound, String prefExpected, String schema)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/parser/PreflightParser.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/parser/PreflightParser.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/parser/PreflightParser.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/parser/PreflightParser.java Sun Oct 26 18:18:37 2014
@@ -124,7 +124,7 @@ public class PreflightParser extends Non
     /**
      * Create an instance of ValidationResult with a ValidationError(UNKNOWN_ERROR)
      * 
-     * @return
+     * @return the ValidationError instance.
      */
     protected static ValidationResult createUnknownErrorResult()
     {
@@ -543,7 +543,7 @@ public class PreflightParser extends Non
     /**
      * Check that the hexa string contains only an even number of Hexadecimal characters. Once it is done, reset the
      * offset at the beginning of the string and call {@link BaseParser#parseCOSString()}
-     * @deprecated Not needed anymore. Use {@link #COSString()} instead. PDFBOX-1437
+     * @deprecated Not needed anymore. Use {@link #parseCOSString()} instead. PDFBOX-1437
      */
     @Override
     @Deprecated

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/AcroFormValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/AcroFormValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/AcroFormValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/AcroFormValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -76,9 +76,8 @@ public class AcroFormValidationProcess e
      * 
      * If the entry is invalid, the ERROR_SYNTAX_DICT_INVALID (1.2.3) error is return.
      * 
-     * @param ctx
-     * @param acroForm
-     * @param result
+     * @param ctx the preflight context.
+     * @param acroForm the AcroForm.
      */
     protected void checkNeedAppearences(PreflightContext ctx, PDAcroForm acroForm)
     {
@@ -92,9 +91,11 @@ public class AcroFormValidationProcess e
     /**
      * This function explores all fields and their children to check if the A or AA entry is present.
      * 
-     * @param ctx
-     * @param acroForm
-     * @param result
+     * @see #valideField(PreflightContext, PDField) 
+     * 
+     * @param ctx the preflight context.
+     * @param lFields the list of fields.
+     * @return the result of the check for A or AA entries.
      * @throws IOException
      */
     protected boolean exploreFields(PreflightContext ctx, List<?> lFields) throws IOException
@@ -119,9 +120,9 @@ public class AcroFormValidationProcess e
      * ERROR_ACTION_FORBIDDEN_WIDGET_ACTION_FIELD (6.2.4) is added to the error list. (Remark : The widget validation
      * will be done by the AnnotationValidationHelper, but some actions are authorized in a standard Widget)
      * 
-     * @param ctx
-     * @param aField
-     * @return
+     * @param ctx the preflight context.
+     * @param aField an acro forms field.
+     * @return the result of the check for A or AA entries.
      * @throws IOException
      */
     protected boolean valideField(PreflightContext ctx, PDField aField) throws IOException

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/BookmarkValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/BookmarkValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/BookmarkValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/BookmarkValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -77,8 +77,8 @@ public class BookmarkValidationProcess e
     /**
      * Return true if the Count entry is present in the given dictionary.
      * 
-     * @param outline
-     * @return
+     * @param outline the dictionary representing the document outline.
+     * @return true if the Count entry is present.
      */
     private boolean isCountEntryPresent(COSDictionary outline)
     {
@@ -88,9 +88,9 @@ public class BookmarkValidationProcess e
     /**
      * return true if Count entry &gt; 0
      * 
-     * @param outline
-     * @param doc
-     * @return
+     * @param ctx the preflight context.
+     * @param outline the dictionary representing the document outline.
+     * @return true if the Count entry &gt; 0.
      */
     private boolean isCountEntryPositive(PreflightContext ctx, COSDictionary outline)
     {
@@ -103,11 +103,9 @@ public class BookmarkValidationProcess e
      * This method explores the Outline Item Level and call a validation method on each Outline Item. If an invalid
      * outline item is found, the result list is updated.
      * 
+     * @param ctx the preflight context.
      * @param inputItem
      *            The first outline item of the level
-     * @param ctx
-     *            The document handler which provides useful data for the level exploration (ex : access to the
-     *            PDDocument)
      * @return true if all items are valid in this level.
      * @throws ValidationException
      */
@@ -129,13 +127,9 @@ public class BookmarkValidationProcess e
      * This method checks the inputItem dictionary and call the exploreOutlineLevel method on the first child if it is
      * not null.
      * 
-     * @param inputItem
-     *            outline item to validate
-     * @param ctx
-     *            The document handler which provides useful data for the level exploration (ex : access to the
-     *            PDDocument)
-     * @param result
-     * @return
+     * @param ctx the preflight context.
+     * @param inputItem outline item to validate
+     * @return the validation result.
      * @throws ValidationException
      */
     protected boolean validateItem(PreflightContext ctx, PDOutlineItem inputItem) throws ValidationException

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/CatalogValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/CatalogValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/CatalogValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/CatalogValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -373,9 +373,8 @@ public class CatalogValidationProcess ex
      * null is returned.
      * 
      * @param destOutputProfile
-     * @param tmpDestOutputProfile
-     * @param ctx
-     * @return
+     * @param mapDestOutputProfile
+     * @param ctx the preflight context.
      * @throws ValidationException
      */
     protected void validateICCProfile(COSBase destOutputProfile, Map<COSObjectKey, Boolean> mapDestOutputProfile,

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/FileSpecificationValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/FileSpecificationValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/FileSpecificationValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/FileSpecificationValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -70,11 +70,9 @@ public class FileSpecificationValidation
     /**
      * Validate a FileSpec dictionary, a FileSpec dictionary mustn't have the EF (EmbeddedFile) entry.
      * 
-     * @param ctx
-     *            The document handler
-     * @param cObj
-     *            the FileSpec Dictionary
-     * @return
+     * @param ctx the preflight context.
+     * @param fileSpec the FileSpec Dictionary.
+     * @return the list of validation errors.
      */
     public List<ValidationError> validateFileSpecification(PreflightContext ctx, COSDictionary fileSpec)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/MetadataValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/MetadataValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/MetadataValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/MetadataValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -192,8 +192,8 @@ public class MetadataValidationProcess e
     /**
      * Check if metadata dictionary has no stream filter
      * 
-     * @param doc
-     * @return
+     * @param doc the document to check.
+     * @return the list of validation errors.
      */
     protected List<ValidationError> checkStreamFilterUsage(PDDocument doc)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/StreamValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/StreamValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/StreamValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/StreamValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -87,9 +87,8 @@ public class StreamValidationProcess ext
      * This method checks if one of declared Filter is LZWdecode. If LZW is found, the result list is updated with an
      * error code.
      * 
-     * @param stream
-     * @param handler
-     * @param result
+     * @param stream the stream to check.
+     * @param context the preflight context.
      */
     protected void checkFilters(COSStream stream, PreflightContext context)
     {
@@ -339,8 +338,8 @@ public class StreamValidationProcess ext
      * Check dictionary entries. Only the Length entry is mandatory. In a PDF/A file, F, FFilter and FDecodeParms are
      * forbidden
      * 
-     * @param streamObj
-     * @param result
+     * @param context the preflight context.
+     * @param streamObj the stream to check.
      */
     protected void checkDictionaryEntries(PreflightContext context, COSStream streamObj)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/TrailerValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/TrailerValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/TrailerValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/TrailerValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -92,8 +92,7 @@ public class TrailerValidationProcess ex
     /**
      * Extracts and compares first and last trailers for PDF version between 1.1 and 1.4
      * 
-     * @param ctx
-     * @param result
+     * @param ctx the preflight context.
      */
     protected void checkTrailersForLinearizedPDF14(PreflightContext ctx)
     {
@@ -119,8 +118,7 @@ public class TrailerValidationProcess ex
     /**
      * Accesses and compares First and Last trailers for a PDF version higher than 1.4.
      * 
-     * @param ctx
-     * @param result
+     * @param ctx the preflight context.
      */
     protected void checkTrailersForLinearizedPDF15(PreflightContext ctx)
     {
@@ -181,9 +179,9 @@ public class TrailerValidationProcess ex
      * Return true if the ID of the first dictionary is the same as the id of the last dictionary Return false
      * otherwise.
      * 
-     * @param first
-     * @param last
-     * @return
+     * @param first the first dictionary for comparison.
+     * @param last the last dictionary for comparison.
+     * @return true if the IDs of the first and last dictionary are the same.
      */
     protected boolean compareIds(COSDictionary first, COSDictionary last, COSDocument cosDocument)
     {
@@ -231,8 +229,8 @@ public class TrailerValidationProcess ex
     /**
      * check if all keys are authorized in a trailer dictionary and if the type is valid.
      * 
-     * @param ctx
-     * @param trailer
+     * @param ctx the preflight context.
+     * @param trailer the trailer dictionary.
      */
     protected void checkMainTrailer(PreflightContext ctx, COSDictionary trailer)
     {
@@ -358,8 +356,8 @@ public class TrailerValidationProcess ex
      * According to the PDF Reference, A linearized PDF contain a dictionary as first object (linearized dictionary) and
      * only this one in the first section.
      * 
-     * @param document
-     * @return
+     * @param document the document to validate.
+     * @return the linearization dictionary or null.
      */
     protected COSDictionary getLinearizedDictionary(PDDocument document)
     {
@@ -381,8 +379,8 @@ public class TrailerValidationProcess ex
     /**
      * Check if mandatory keys of linearized dictionary are present.
      * 
-     * @param ctx
-     * @param linearizedDict
+     * @param ctx the preflight context.
+     * @param linearizedDict the linearization dictionary.
      */
     protected void checkLinearizedDictionnary(PreflightContext ctx, COSDictionary linearizedDict)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ExtGStateValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ExtGStateValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ExtGStateValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ExtGStateValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -52,6 +52,12 @@ import org.apache.pdfbox.preflight.utils
 public class ExtGStateValidationProcess extends AbstractProcess
 {
 
+    /**
+     * Validate the ExtGState dictionaries.
+     * 
+     * @param context the context which contains the Resource dictionary.
+     * @throws ValidationException thrown if a the Extended Graphic State isn't valid.
+     */
     public void validate(PreflightContext context) throws ValidationException
     {
         PreflightPath vPath = context.getValidationPath();
@@ -71,14 +77,12 @@ public class ExtGStateValidationProcess 
     }
 
     /**
-     * Create a list Of ExtGState dictionaries using the given Resource dictionary and the COSDocument.
+     * Create a list of ExtGState dictionaries using the given Resource dictionary and the COSDocument.
      * 
-     * @param context
-     *            the context which contains the Resource dictionary
-     * @param resources
-     *            a resource COSDictionary
-     * @throws ValidationException
-     *             thrown if a the Extended Graphic State isn't valid
+     * @param context the context which contains the Resource dictionary.
+     * @param egsEntry a resource COSDictionary.
+     * @return the list of ExtGState dictionaries.
+     * @throws ValidationException thrown if a the Extended Graphic State isn't valid.
      */
     public List<COSDictionary> extractExtGStateDictionaries(PreflightContext context, COSDictionary egsEntry)
             throws ValidationException
@@ -110,6 +114,9 @@ public class ExtGStateValidationProcess 
     /**
      * Validate all ExtGState dictionaries of this container
      * 
+     * @param context the preflight context.
+     * @param listOfExtGState a list of ExtGState COSDictionaries.
+     * 
      */
     protected void validateTransparencyRules(PreflightContext context, List<COSDictionary> listOfExtGState)
     {
@@ -127,8 +134,8 @@ public class ExtGStateValidationProcess 
      * This method checks the SMask value of the ExtGState dictionary. The Soft Mask is optional but must be "None" if
      * it is present.
      * 
-     * @param egs
-     *            the Graphic state to check
+     * @param context the preflight context.
+     * @param egs the Graphic state to check
      */
     private void checkSoftMask(PreflightContext context, COSDictionary egs)
     {
@@ -149,8 +156,7 @@ public class ExtGStateValidationProcess 
      * This method checks the BM value of the ExtGState dictionary. The Blend Mode is optional but must be "Normal" or
      * "Compatible" if it is present.
      * 
-     * @param egs
-     *            the graphic state to check
+     * @param context the preflight context     * @param egs the graphic state to check
      */
     private void checkBlendMode(PreflightContext context, COSDictionary egs)
     {
@@ -171,8 +177,8 @@ public class ExtGStateValidationProcess 
      * This method checks the "CA" and "ca" values of the ExtGState dictionary. They are optional but must be 1.0 if
      * they are present.
      * 
-     * @param egs
-     *            the graphic state to check
+     * @param context the preflight context.
+     * @param egs the graphic state to check
      */
     private void checkCA(PreflightContext context, COSDictionary egs)
     {
@@ -208,8 +214,8 @@ public class ExtGStateValidationProcess 
     /**
      * Check the TR entry. A valid ExtGState hasn't TR entry.
      * 
-     * @param egs
-     *            the graphic state to check
+     * @param context the preflight context
+     * @param egs the graphic state to check
      */
     protected void checkTRKey(PreflightContext context, COSDictionary egs)
     {
@@ -223,8 +229,7 @@ public class ExtGStateValidationProcess 
     /**
      * Check the TR2 entry. A valid ExtGState hasn't TR2 entry or a TR2 entry equals to "default".
      * 
-     * @param egs
-     *            the graphic state to check
+     * @param egs the graphic state to check
      */
     protected void checkTR2Key(PreflightContext context, COSDictionary egs)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/FontValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/FontValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/FontValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/FontValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -78,8 +78,9 @@ public class FontValidationProcess exten
     /**
      * Create the right "Validator" object for the given font type
      * 
-     * @param font
-     * @return
+     * @param context the preflight context.
+     * @param font the font object.
+     * @return the font validator instance for the font type.
      */
     protected FontValidator<? extends FontContainer> getFontValidator(PreflightContext context, PDFont font)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ShaddingPatternValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ShaddingPatternValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ShaddingPatternValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/ShaddingPatternValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -71,9 +71,9 @@ public class ShaddingPatternValidationPr
      * 
      * This method is called by the validate method.
      * 
-     * @param shadingRes
-     *            the Shading pattern to check
-     * @return true if the Shading pattern is valid, false otherwise.
+     * @param context the preflight context.
+     * @param page the page to check.
+     * @param shadingRes the Shading pattern to check.
      * @throws ValidationException
      */
     protected void checkColorSpace(PreflightContext context, PDPage page, PDShading shadingRes)
@@ -97,7 +97,9 @@ public class ShaddingPatternValidationPr
      * Check the Extended Graphic State contains in the ShadingPattern dictionary if it is present. To check this
      * ExtGState, this method uses the net.awl.edoc.pdfa.validation.graphics.ExtGStateContainer object.
      * 
-     * @return true is the ExtGState is missing or valid, false otherwise.
+     * @param context the preflight context.
+     * @param page the page to check.
+     * @param shadingRes the Shading pattern to check.
      * @throws ValidationException
      */
     protected void checkGraphicState(PreflightContext context, PDPage page, PDShading shadingRes)

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/SinglePageValidationProcess.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/SinglePageValidationProcess.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/SinglePageValidationProcess.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/process/reflect/SinglePageValidationProcess.java Sun Oct 26 18:18:37 2014
@@ -91,9 +91,8 @@ public class SinglePageValidationProcess
     /**
      * This method checks additional actions contained in the given Page object.
      * 
-     * @param context
-     * @param page
-     * @return
+     * @param context the preflight context.
+     * @param page the page to check.
      * @throws ValidationException
      */
     protected void validateActions(PreflightContext context, PDPage page) throws ValidationException
@@ -105,8 +104,8 @@ public class SinglePageValidationProcess
      * Check that all ColorSpace present in the Resource dictionary are conforming to the ISO 19005:2005-1
      * specification.
      * 
-     * @param context
-     * @param page
+     * @param context the preflight context.
+     * @param page the page to check.
      */
     protected void validateColorSpaces(PreflightContext context, PDPage page) throws ValidationException
     {
@@ -137,8 +136,8 @@ public class SinglePageValidationProcess
      * Check that all XObject references in the PDResource of the page and in the Thumb entry are confirming to the
      * PDF/A specification.
      * 
-     * @param context
-     * @param page
+     * @param context the preflight context.
+     * @param page the page to check.
      * @throws ValidationException
      */
     protected void validateGraphicObjects(PreflightContext context, PDPage page) throws ValidationException
@@ -170,9 +169,8 @@ public class SinglePageValidationProcess
 
     /**
      * 
-     * @param page
-     * @param context
-     * @return
+     * @param context the preflight context.
+     * @param page the page to check.
      * @throws ValidationException
      */
     protected void validateContent(PreflightContext context, PDPage page) throws ValidationException
@@ -191,8 +189,8 @@ public class SinglePageValidationProcess
 
     /**
      * 
-     * @param page
-     * @return
+     * @param context the preflight context.
+     * @param page the page to check.
      * @throws ValidationException
      */
     protected void validateAnnotation(PreflightContext context, PDPage page) throws ValidationException
@@ -223,8 +221,8 @@ public class SinglePageValidationProcess
     /**
      * Check that the group dictionary doesn't have a Transparency attribute
      * 
-     * @param context
-     * @param page
+     * @param context the preflight context.
+     * @param page the page to check.
      * @throws ValidationException
      */
     protected void validateGroupTransparency(PreflightContext context, PDPage page) throws ValidationException

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/COSUtils.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/COSUtils.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/COSUtils.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/COSUtils.java Sun Oct 26 18:18:37 2014
@@ -46,9 +46,9 @@ public class COSUtils
     /**
      * return true if the elt is a COSDictionary or a reference to a COSDictionary
      * 
-     * @param elt
-     * @param doc
-     * @return
+     * @param elt the object to check.
+     * @param doc the document.
+     * @return true if the object is a COSDictionary or a reference to it.
      */
     public static boolean isDictionary(COSBase elt, COSDocument doc)
     {
@@ -71,9 +71,9 @@ public class COSUtils
     /**
      * return true if the elt is a COSString or a reference to a COSString
      * 
-     * @param elt
-     * @param doc
-     * @return
+     * @param elt the object to check.
+     * @param doc the document.
+     * @return true if the object is a COSString or a reference to it.
      */
     public static boolean isString(COSBase elt, COSDocument doc)
     {
@@ -97,9 +97,9 @@ public class COSUtils
     /**
      * return true if the elt is a COSStream or a reference to a COSStream
      * 
-     * @param elt
-     * @param doc
-     * @return
+     * @param elt the object to check.
+     * @param doc the document.
+     * @return true if the object is a COSStream or a reference to it.
      */
     public static boolean isStream(COSBase elt, COSDocument doc)
     {
@@ -123,9 +123,9 @@ public class COSUtils
     /**
      * return true if the elt is a COSInteger or a reference to a COSInteger
      * 
-     * @param elt
-     * @param doc
-     * @return
+     * @param elt the object to check.
+     * @param doc the document.
+     * @return true if the object is a COSInteger or a reference to it.
      */
     public static boolean isInteger(COSBase elt, COSDocument doc)
     {
@@ -149,9 +149,9 @@ public class COSUtils
     /**
      * return true if elt is COSInteger or COSFloat
      * 
-     * @param elt
-     * @param doc
-     * @return boolean
+     * @param elt the object to check.
+     * @param doc the document.
+     * @return true if the object is a COSInteger, COSFloat or a reference to it.
      */
     public static boolean isNumeric(COSBase elt, COSDocument doc)
     {
@@ -159,11 +159,11 @@ public class COSUtils
     }
 
     /**
-     * return true if the elt is a COSInteger or a reference to a COSInteger
+     * return true if the elt is a COSFloat or a reference to a COSFloat
      * 
-     * @param elt
-     * @param doc
-     * @return
+     * @param elt the object to check.
+     * @param doc the document.
+     * @return true if the object is a COSFloat or a reference to it.
      */
     public static boolean isFloat(COSBase elt, COSDocument doc)
     {
@@ -187,9 +187,9 @@ public class COSUtils
     /**
      * return true if the elt is a COSArray or a reference to a COSArray
      * 
-     * @param elt
-     * @param doc
-     * @return
+     * @param elt the object to check.
+     * @param doc the document.
+     * @return true if the object is a COSArray or a reference to it.
      */
     public static boolean isArray(COSBase elt, COSDocument doc)
     {
@@ -214,9 +214,9 @@ public class COSUtils
      * Return the COSBase object as COSArray if the COSBase object is an instance of COSArray or a reference to a
      * COSArray object. In other cases, this method returns null;
      * 
-     * @param cbase
-     * @param cDoc
-     * @return
+     * @param cbase the object to get.
+     * @param cDoc the document.
+     * @return the object as COSArray if the object is a COSArray or a reference to it. Returns null otherwise.
      */
     public static COSArray getAsArray(COSBase cbase, COSDocument cDoc)
     {
@@ -254,9 +254,9 @@ public class COSUtils
      * Return the COSBase object as COSString if the COSBase object is an instance of COSString or a reference to a
      * COSString object. In other cases, this method returns null;
      * 
-     * @param cbase
-     * @param cDoc
-     * @return
+     * @param cbase the object to get.
+     * @param cDoc the document.
+     * @return the object as COSString if the object is a COSString or a reference to it. Returns null otherwise.
      */
     public static String getAsString(COSBase cbase, COSDocument cDoc)
     {
@@ -302,9 +302,9 @@ public class COSUtils
      * Return the COSBase object as COSDictionary if the COSBase object is an instance of COSDictionary or a reference
      * to a COSDictionary object. In other cases, this method returns null;
      * 
-     * @param cbase
-     * @param cDoc
-     * @return
+     * @param cbase the object to get.
+     * @param cDoc the document.
+     * @return the object as COSDictionary if the object is a COSDictionary or a reference to it. Returns null otherwise.
      */
     public static COSDictionary getAsDictionary(COSBase cbase, COSDocument cDoc)
     {
@@ -342,9 +342,9 @@ public class COSUtils
      * Return the COSBase object as COSStream if the COSBase object is an instance of COSStream or a reference to a
      * COSStream object. In other cases, this method returns null;
      * 
-     * @param cbase
-     * @param cDoc
-     * @return
+     * @param cbase the object to get.
+     * @param cDoc the document.
+     * @return the object as COSStream if the object is a COSStream or a reference to it. Returns null otherwise.
      */
     public static COSStream getAsStream(COSBase cbase, COSDocument cDoc)
     {
@@ -382,9 +382,9 @@ public class COSUtils
      * Return the COSBase object as Float if the COSBase object is an instance of COSFloat or a reference to a COSFloat
      * object. In other cases, this method returns null;
      * 
-     * @param cbase
-     * @param cDoc
-     * @return
+     * @param cbase the object to get.
+     * @param cDoc the document.
+     * @return the object as Float if the object is a COSFloat or a reference to it. Returns null otherwise.
      */
     public static Float getAsFloat(COSBase cbase, COSDocument cDoc)
     {
@@ -434,9 +434,9 @@ public class COSUtils
      * Return the COSBase object as Integer if the COSBase object is an instance of COSInteger or a reference to a
      * COSInteger object. In other cases, this method returns null;
      * 
-     * @param cbase
-     * @param cDoc
-     * @return
+     * @param cbase the object to get.
+     * @param cDoc the document.
+     * @return the object as Integer if the object is a COSInteger or a reference to it. Returns null otherwise.
      */
     public static Integer getAsInteger(COSBase cbase, COSDocument cDoc)
     {
@@ -486,7 +486,7 @@ public class COSUtils
      * Close the given Document. If the close method of the document throws an
      * exception, it is logged using a commons logger (Level : WARN)
      *
-     * @param document
+     * @param document the document.
      */
     public static void closeDocumentQuietly(COSDocument document)
     {
@@ -507,7 +507,7 @@ public class COSUtils
      * Close the given Document. If the close method of the document throws an
      * exception, it is logged using a commons logger (Level : WARN)
       * 
-     * @param document
+     * @param document the document.
      */
     public static void closeDocumentQuietly(PDDocument document)
     {

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/PdfElementParser.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/PdfElementParser.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/PdfElementParser.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/utils/PdfElementParser.java Sun Oct 26 18:18:37 2014
@@ -63,7 +63,7 @@ public class PdfElementParser extends Ba
     /**
      * Return the COSDocument used to create this object.
      * 
-     * @return
+     * @return the document.
      */
     public COSDocument getDocument()
     {
--- pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToAction.java (original)
+++ pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToAction.java Sun Oct 26 18:18:37 2014
@@ -40,18 +40,14 @@ public class GoToAction extends Abstract
 
     /**
      * 
      * @param amFact
      *            Instance of ActionManagerFactory used to create ActionManager to check Next actions.
      * @param adict
      *            the COSDictionary of the action wrapped by this class.
      * @param cDoc
      *            the COSDocument from which the action comes from.
      * @param aa
      *            The name of the key which identify the action in a additional action dictionary.
      */
-    public GoToAction(ActionManagerFactory amFact, COSDictionary adict, PreflightContext ctx, String aa)
+    public GoToAction(ActionManagerFactory amFact, COSDictionary adict, PreflightContext ctx, String aaKey)
     {
-        super(amFact, adict, ctx, aa);
+        super(amFact, adict, ctx, aaKey);
     }
 
     /*
@@ -40,18 +40,14 @@ public class GoToAction extends Abstract
     /**
      * 
-     * @param amFact
-     *            Instance of ActionManagerFactory used to create ActionManager to check Next actions.
-     * @param adict
-     *            the COSDictionary of the action wrapped by this class.
-     * @param cDoc
-     *            the COSDocument from which the action comes from.
-     * @param aa
-     *            The name of the key which identify the action in a additional action dictionary.
+     * @param amFact Instance of ActionManagerFactory used to create ActionManager to check Next actions.
+     * @param adict the COSDictionary of the action wrapped by this class.
+     * @param ctx the preflight context.
+     * @param aaKey the name of the key which identifies the action in an additional action dictionary.
      */

Modified: pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToRemoteAction.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/preflight/src/main/java/org/apache/pdfbox/preflight/action/GoToRemoteAction.java?rev=1634371&r1=1634370&r2=1634371&view=diff
==============================================================================